Connectors & Connectivity – Tagged "s1_Component Parts" – RadioShack

- Twitter
- Facebook
- Instagram
- Pinterest
- Youtube
- Google Plus

# Component Parts

Online In Store
Sort by
Filters
View: List Grid
RadioShack® Project Enclosure (3x2x1") $3.49
Perfect for electronic hobbies, science kits and more! Constructed of durable ABS plastic, this enclosure features four standoffs in the bottom corners to support a PC board. Standoffs are 1/4" hi...
RadioShack® Enclosed 2 “AA” Battery Holder $2.49
This enclosed wire connector battery holder holds 2 “AA” batteries and has color-coded wire leads.
RadioShack® “AA” Battery Holder $1.49
This wire connector battery holder holds 1 “AA” battery and has color-coded wire leads.
RadioShack® Enclosed 4 “AA” Battery Holder $2.49
This enclosed 4 "AA" battery holder has a built-in on-off switch and has color-coded wire leads.
RadioShack® 8 “AA” Battery Holder $2.99
This snap connector battery holder holds 8 “AA” batteries.
RadioShack® Super Speed 9-18VDC Hobby Motor $5.99
Add motion to projects! This motor is perfect for solar power demonstrations, robotics, models, science projects and more. And it operates on three different voltage inputs: 9, 12 and 18V DC.
RadioShack® 4 “AA” Battery Holder $2.49
4 AA battery holder with snap connector end. Great for your projects or building your own battery packs.
RadioShack® Project Enclosure (4x2x1") $3.99
Perfect for electronic hobbies, science kits and more! Constructed of durable ABS plastic, this enclosure features four standoffs in the bottom corners to support a PC board. Standoffs are 1/4" hi...
RadioShack® CR2032 Battery Holder $2.49
This CR2032 battery holder is perfect as a replacement or for project use. It has a low-profile dip-style design for densely packed boards.
RadioShack® Mini Audio Amplifier $14.99
With a built in speaker, this mini audio amplifier is perfect for many acoustic projects. Also includes a microphone input and a speaker/earphone jack for added flexibility.
RadioShack® 8 “AA” Battery Holder $2.99
This battery holder holds 8 “AA” batteries and has a snap connector design for easy installation.
RadioShack® 3VDC Micro-Vibration Motor $3.99
Use this 3VDC micro-vibration motor in your project. Get no-load speed of 13000 RPM.

## Please enter ZIP code:

Enter 5 digit zip code

Loading...